==> lxqt-l10n_0.10.9.orig.tar.xz: lxqt-l10n-0.10.9/lxqt-panel/plugin-sensors/sensors_uk.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="uk">
<context>
    <name>LXQtSensorsConfiguration</name>
    <message>
        <source>LXQt Sensors Settings</source>
        <translation type="vanished">Налаштування сенсорів LXQt</translation>
    </message>
    <message>
        <location filename="../../../lxqtsensorsconfiguration.ui" line="14"/>
        <source>Sensors Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqtsensorsconfiguration.ui" line="30"/>
        <source>Common</source>
        <translation>Загальне</translation>
    </message>
    <message>
        <location filename="../../../lxqtsensorsconfiguration.ui" line="42"/>
        <source>Update interval (seconds)</source>
        <translation>Період поновлення (в секундах)</translation>
    </message>
    <message>
        <location filename="../../../lxqtsensorsconfiguration.ui" line="49"/>
        <source>Temperature bar width</source>
        <translation>Ширина планки температури</translation>
    </message>
    <message>
        <location filename="../../../lxqtsensorsconfiguration.ui" line="104"/>
        <source>Temperature scale</source>
        <translation>Шкала температури</translation>
    </message>
    <message>
        <location filename="../../../lxqtsensorsconfiguration.ui" line="110"/>
        <source>Celsius</source>
        <translation>Цельсія</translation>
    </message>
    <message>
        <location filename="../../../lxqtsensorsconfiguration.ui" line="120"/>
        <source>Fahrenheit</source>
        <translation>Фаренгейта</translation>
    </message>
    <message>
        <location filename="../../../lxqtsensorsconfiguration.ui" line="132"/>
        <source>Blink progress bars when the temperature is too high</source>
        <translation>Блимати планками прогресу при занадто високій температурі</translation>
    </message>
    <message>
        <location filename="../../../lxqtsensorsconfiguration.ui" line="138"/>
        <source>Warning about high temperature</source>
        <translation>Попереджати про високу температуру</translation>
    </message>
    <message>
        <location filename="../../../lxqtsensorsconfiguration.ui" line="152"/>
        <source>Sensors</source>
        <translation>Сенсори</translation>
    </message>
    <message>
        <location filename="../../../lxqtsensorsconfiguration.ui" line="168"/>
        <source>Detected chips:</source>
        <translation>Виявлені мікросхеми:</translation>
    </message>
    <message>
        <location filename="../../../lxqtsensorsconfiguration.ui" line="175"/>
        <source>Chip features:</source>
        <translation>Особливості мікросхеми:</translation>
    </message>
    <message>
        <location filename="../../../lxqtsensorsconfiguration.cpp" line="212"/>
        <source>Enabled</source>
        <translation>Включено</translation>
    </message>
    <message>
        <location filename="../../../lxqtsensorsconfiguration.cpp" line="212"/>
        <source>Label</source>
        <translation>Позначка</translation>
    </message>
    <message>
        <location filename="../../../lxqtsensorsconfiguration.cpp" line="212"/>
        <source>Color</source>
        <translation>Колір</translation>
    </message>
</context>
</TS>

==> lxqt-l10n-0.13.0_p20181121.tar.xz: lxqt-l10n-0.13.0_p20181121/lxqt-panel/plugin-sensors/sensors_uk.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="uk">
<context>
    <name>LXQtSensorsConfiguration</name>
    <message>
        <source>LXQt Sensors Settings</source>
        <translation type="vanished">Налаштування сенсорів LXQt</translation>
    </message>
    <message>
        <location filename="../../../lxqtsensorsconfiguration.ui" line="14"/>
        <source>Sensors Settings</source>
        <translation>Налаштування сенсорів</translation>
    </message>
    <message>
        <location filename="../../../lxqtsensorsconfiguration.ui" line="30"/>
        <source>Common</source>
        <translation>Загальне</translation>
    </message>
    <message>
        <location filename="../../../lxqtsensorsconfiguration.ui" line="42"/>
        <source>Update interval (seconds)</source>
        <translation>Період поновлення (в секундах)</translation>
    </message>
    <message>
        <location filename="../../../lxqtsensorsconfiguration.ui" line="49"/>
        <source>Temperature bar width</source>
        <translation>Ширина планки температури</translation>
    </message>
    <message>
        <location filename="../../../lxqtsensorsconfiguration.ui" line="104"/>
        <source>Temperature scale</source>
        <translation>Шкала температури</translation>
    </message>
    <message>
        <location filename="../../../lxqtsensorsconfiguration.ui" line="110"/>
        <source>Celsius</source>
        <translation>Цельсія</translation>
    </message>
    <message>
        <location filename="../../../lxqtsensorsconfiguration.ui" line="120"/>
        <source>Fahrenheit</source>
        <translation>Фаренгейта</translation>
    </message>
    <message>
        <location filename="../../../lxqtsensorsconfiguration.ui" line="132"/>
        <source>Blink progress bars when the temperature is too high</source>
        <translation>Блимати планками прогресу при занадто високій температурі</translation>
    </message>
    <message>
        <location filename="../../../lxqtsensorsconfiguration.ui" line="138"/>
        <source>Warning about high temperature</source>
        <translation>Попереджати про високу температуру</translation>
    </message>
    <message>
        <location filename="../../../lxqtsensorsconfiguration.ui" line="152"/>
        <source>Sensors</source>
        <translation>Сенсори</translation>
    </message>
    <message>
        <location filename="../../../lxqtsensorsconfiguration.ui" line="168"/>
        <source>Detected chips:</source>
        <translation>Виявлені чіпи:</translation>
    </message>
    <message>
        <location filename="../../../lxqtsensorsconfiguration.ui" line="175"/>
        <source>Chip features:</source>
        <translation>Особливості мікросхеми:</translation>
    </message>
    <message>
        <location filename="../../../lxqtsensorsconfiguration.cpp" line="195"/>
        <source>Enabled</source>
        <translation>Включено</translation>
    </message>
    <message>
        <location filename="../../../lxqtsensorsconfiguration.cpp" line="195"/>
        <source>Label</source>
        <translation>Мітка</translation>
    </message>
    <message>
        <location filename="../../../lxqtsensorsconfiguration.cpp" line="195"/>
        <source>Color</source>
        <translation>Колір</translation>
    </message>
</context>
</TS>
